package __test

import (
	"fmt"

	omd "git.loafle.net/overflow/model/discovery"
	omm "git.loafle.net/overflow/model/meta"
)

const (
	ZONE_NETWORK = "192.168.1"
	ZONE_IFACE   = "enp3s0"
	ZONE_ADDRESS = "101"
	ZONE_MAC     = "44:8a:5b:f1:f1:f3"
)

// const (
// 	ZONE_NETWORK = "192.168.1"
// 	ZONE_IFACE   = "\\Device\\NPF_{1924FA2B-6927-4BA5-AF43-876C3F8853CE}"
// 	ZONE_ADDRESS = "103"
// 	ZONE_MAC     = "30:9C:23:15:A3:09"
// )

func Zone() *omd.Zone {
	return omd.NewZone(
		ZONE_IFACE,
		ZONE_MAC,
		omm.ToMetaIPType(omm.MetaIPTypeEnumV4),
		fmt.Sprintf("%s.0/24", ZONE_NETWORK),
		fmt.Sprintf("%s.%s", ZONE_NETWORK, ZONE_ADDRESS),
	)
}

func Host(hostName string, address string, mac string) *omd.Host {
	h := omd.NewHost(
		Zone(),
		omm.ToMetaIPType(omm.MetaIPTypeEnumV4),
		fmt.Sprintf("%s.%s", ZONE_NETWORK, address),
	)
	h.Name = hostName
	h.Mac = mac

	return h
}

func Port(host *omd.Host, port int) *omd.Port {
	return omd.NewPort(
		host,
		omm.ToMetaPortType(omm.MetaPortTypeEnumTCP),
		port,
	)
}

func DiscoveryConfig() *omd.DiscoveryConfig {
	return &omd.DiscoveryConfig{}
}

func DiscoverHost(discoveryConfig *omd.DiscoveryConfig, firstScanRange int, lastScanRange int, discoverPort *omd.DiscoverPort) *omd.DiscoverHost {
	return &omd.DiscoverHost{
		MetaIPType:      omm.ToMetaIPType(omm.MetaIPTypeEnumV4),
		FirstScanRange:  fmt.Sprintf("%s.%d", ZONE_NETWORK, firstScanRange),
		LastScanRange:   fmt.Sprintf("%s.%d", ZONE_NETWORK, lastScanRange),
		DiscoveryConfig: discoveryConfig,
		DiscoverPort:    discoverPort,
	}
}

func DiscoverPort(discoveryConfig *omd.DiscoveryConfig, firstScanRange int, lastScanRange int, includeTCP bool, includeUDP bool, discoverService *omd.DiscoverService) *omd.DiscoverPort {
	return &omd.DiscoverPort{
		FirstScanRange:  firstScanRange,
		LastScanRange:   lastScanRange,
		IncludeTCP:      includeTCP,
		IncludeUDP:      includeUDP,
		DiscoverService: discoverService,
	}
}

func DiscoverService(discoveryConfig *omd.DiscoveryConfig) *omd.DiscoverService {
	return &omd.DiscoverService{
		DiscoveryConfig: discoveryConfig,
	}
}
